@@ -67,6 +67,7 @@ MAX_RETRIES_HELP = (
     "Maximum number of times to retry model API requests (defaults to unlimited)"
 )
 TIMEOUT_HELP = "Model API request timeout in seconds (defaults to no timeout)"
+ATTEMPT_TIMEOUT_HELP = "Timeout (in seconds) for any given attempt (if exceeded, will abandon attempt and retry according to max_retries)."
 BATCH_HELP = "Batch requests together to reduce API calls when using a model that supports batching (by default, no batching). Specify --batch to batch with default configuration,  specify a batch size e.g. `--batch=1000` to configure batches of 1000 requests, or pass the file path to a YAML or JSON config file with batch configuration."
 
 
@@ -231,6 +232,12 @@ def eval_options(func: Callable[..., Any]) -> Callable[..., click.Context]:
     @click.option(
         "--timeout", type=int, help=TIMEOUT_HELP, envvar="INSPECT_EVAL_TIMEOUT"
     )
+    @click.option(
+        "--attempt-timeout",
+        type=int,
+        help=ATTEMPT_TIMEOUT_HELP,
+        envvar="INSPECT_EVAL_ATTEMPT_TIMEOUT",
+    )
     @click.option(
         "--max-samples",
         type=int,
@@ -432,13 +439,13 @@ def eval_options(func: Callable[..., Any]) -> Callable[..., click.Context]:
         "--logprobs",
         type=bool,
         is_flag=True,
-        help="Return log probabilities of the output tokens. OpenAI, Grok, TogetherAI, Huggingface, llama-cpp-python, and vLLM only.",
+        help="Return log probabilities of the output tokens. OpenAI, Google, Grok, TogetherAI, Huggingface, llama-cpp-python, and vLLM only.",
         envvar="INSPECT_EVAL_LOGPROBS",
     )
     @click.option(
         "--top-logprobs",
         type=int,
-        help="Number of most likely tokens (0-20) to return at each token position, each with an associated log probability. OpenAI, Grok, TogetherAI, Huggingface, and vLLM only.",
+        help="Number of most likely tokens (0-20) to return at each token position, each with an associated log probability. OpenAI, Google, Grok, TogetherAI, Huggingface, and vLLM only.",
         envvar="INSPECT_EVAL_TOP_LOGPROBS",
     )
     @click.option(
@@ -561,6 +568,7 @@ def eval_command(
     sample_shuffle: int | None,
     max_retries: int | None,
     timeout: int | None,
+    attempt_timeout: int | None,
     max_connections: int | None,
     max_tokens: int | None,
     system_message: str | None,
@@ -750,6 +758,7 @@ def eval_set_command(
     sample_shuffle: int | None,
     max_retries: int | None,
     timeout: int | None,
+    attempt_timeout: int | None,
     max_connections: int | None,
     max_tokens: int | None,
     system_message: str | None,
@@ -1234,6 +1243,12 @@ def parse_comma_separated(value: str | None) -> list[str] | None:
     "--max-retries", type=int, help=MAX_RETRIES_HELP, envvar="INSPECT_EVAL_MAX_RETRIES"
 )
 @click.option("--timeout", type=int, help=TIMEOUT_HELP, envvar="INSPECT_EVAL_TIMEOUT")
+@click.option(
+    "--attempt-timeout",
+    type=int,
+    help=ATTEMPT_TIMEOUT_HELP,
+    envvar="INSPECT_EVAL_ATTEMPT_TIMEOUT",
+)
 @click.option(
     "--log-level-transcript",
     type=click.Choice(
@@ -1267,6 +1282,7 @@ def eval_retry_command(
     max_connections: int | None,
     max_retries: int | None,
     timeout: int | None,
+    attempt_timeout: int | None,
     log_level_transcript: str,
     **common: Unpack[CommonOptions],
 ) -> None:
@@ -1322,5 +1338,6 @@ def eval_retry_command(
         score_display=score_display,
         max_retries=max_retries,
         timeout=timeout,
+        attempt_timeout=attempt_timeout,
         max_connections=max_connections,
     )
