@@ -18,21 +18,21 @@ from inspect_ai._util.transcript import (
     transcript_reasoning,
     transcript_separator,
 )
-from inspect_ai.log._samples import ActiveSample
-from inspect_ai.log._transcript import (
-    ApprovalEvent,
-    ErrorEvent,
+from inspect_ai.event._approval import ApprovalEvent
+from inspect_ai.event._error import ErrorEvent
+from inspect_ai.event._event import (
     Event,
-    InfoEvent,
-    InputEvent,
-    LoggerEvent,
-    ModelEvent,
-    SampleInitEvent,
-    SampleLimitEvent,
-    ScoreEvent,
-    SpanBeginEvent,
-    SubtaskEvent,
 )
+from inspect_ai.event._info import InfoEvent
+from inspect_ai.event._input import InputEvent
+from inspect_ai.event._logger import LoggerEvent
+from inspect_ai.event._model import ModelEvent
+from inspect_ai.event._sample_init import SampleInitEvent
+from inspect_ai.event._sample_limit import SampleLimitEvent
+from inspect_ai.event._score import ScoreEvent
+from inspect_ai.event._span import SpanBeginEvent
+from inspect_ai.event._subtask import SubtaskEvent
+from inspect_ai.log._samples import ActiveSample
 from inspect_ai.model._chat_message import (
     ChatMessage,
     ChatMessageTool,
