@@ -7,11 +7,11 @@ from typing import Any, Literal, cast
 import anyio
 from anyio.abc import TaskGroup
 
-from inspect_ai._eval.task.task import resolve_model_roles
 from inspect_ai._util.notgiven import NOT_GIVEN, NotGiven
 from inspect_ai.agent._agent import Agent, is_agent
 from inspect_ai.agent._as_solver import as_solver
-from inspect_ai.log._model import model_roles_config_to_model_roles
+from inspect_ai.model._model_config import model_roles_config_to_model_roles
+from inspect_ai.model._util import resolve_model_roles
 from inspect_ai.util._anyio import inner_exception
 
 if sys.version_info < (3, 11):
@@ -453,7 +453,8 @@ async def eval_async(
         raise inner_exception(ex)
     except anyio.get_cancelled_exc_class():
         # Cancelled exceptions are expected and handled by _eval_async_inner
-        pass
+        if result is None:
+            raise
 
     assert result is not None, "Eval async did not return a result."
 
@@ -664,7 +665,7 @@ async def _eval_async_inner(
         # single task definition (could be multi-model) or max_tasks capped to 1
         if parallel == 1:
             results: list[EvalLog] = []
-            for sequence in range(0, task_definitions):
+            for sequence in sorted(set(t.sequence for t in resolved_tasks)):
                 task_batch = list(
                     filter(lambda t: t.sequence == sequence, resolved_tasks)
                 )
@@ -725,7 +726,7 @@ async def _eval_async_inner(
             await emit_run_end(eval_set_id, run_id, EvalLogs([]))
         _eval_async_running = False
 
-    except Exception as e:
+    except BaseException as e:
         await emit_run_end(eval_set_id, run_id, EvalLogs([]), e)
         _eval_async_running = False
         raise e
@@ -760,6 +761,7 @@ def eval_retry(
     score_display: bool | None = None,
     max_retries: int | None = None,
     timeout: int | None = None,
+    attempt_timeout: int | None = None,
     max_connections: int | None = None,
 ) -> list[EvalLog]:
     """Retry a previously failed evaluation task.
@@ -811,6 +813,8 @@ def eval_retry(
             Maximum number of times to retry request.
         timeout:
             Request timeout (in seconds)
+        attempt_timeout:
+            Timeout (in seconds) for any given attempt (if exceeded, will abandon attempt and retry according to max_retries).
         max_connections:
             Maximum number of concurrent connections to Model API (default is per Model API)
 
@@ -848,6 +852,7 @@ def eval_retry(
             score_display=score_display,
             max_retries=max_retries,
             timeout=timeout,
+            attempt_timeout=attempt_timeout,
             max_connections=max_connections,
         )
 
@@ -878,6 +883,7 @@ async def eval_retry_async(
     score_display: bool | None = None,
     max_retries: int | None = None,
     timeout: int | None = None,
+    attempt_timeout: int | None = None,
     max_connections: int | None = None,
 ) -> list[EvalLog]:
     """Retry a previously failed evaluation task.
@@ -919,6 +925,7 @@ async def eval_retry_async(
         score_display: Show scoring metrics in realtime (defaults to True)
         max_retries: Maximum number of times to retry request.
         timeout: Request timeout (in seconds)
+        attempt_timeout: Timeout (in seconds) for any given attempt (if exceeded, will abandon attempt and retry according to max_retries).
         max_connections: Maximum number of concurrent connections to Model API (default is per Model API)
 
     Returns:
@@ -1063,6 +1070,7 @@ async def eval_retry_async(
         config = eval_log.plan.config
         config.max_retries = max_retries or config.max_retries
         config.timeout = timeout or config.timeout
+        config.attempt_timeout = attempt_timeout or config.attempt_timeout
         config.max_connections = max_connections or config.max_connections
 
         # run the eval
