@@ -2,20 +2,18 @@ import ast
 import contextlib
 import inspect
 import os
-from importlib.machinery import SourceFileLoader
-from importlib.util import module_from_spec, spec_from_loader
 from logging import getLogger
 from pathlib import Path
-from types import ModuleType
 from typing import Any, Callable, Tuple, cast
 
-from typing_extensions import overload
+from shortuuid import uuid
 
 from inspect_ai._eval.task.resolved import ResolvedTask
 from inspect_ai._eval.task.util import task_file, task_run_dir
 from inspect_ai._util.decorator import parse_decorators
 from inspect_ai._util.error import PrerequisiteError
 from inspect_ai._util.logger import warn_once
+from inspect_ai._util.module import load_module
 from inspect_ai._util.path import chdir_python, cwd_relative_path
 from inspect_ai._util.registry import (
     RegistryInfo,
@@ -65,6 +63,7 @@ def resolve_tasks(
 
         return [
             ResolvedTask(
+                id=uuid(),
                 task=task,
                 task_args=resolve_task_args(task),
                 task_file=task_file(task, relative=True),
@@ -126,7 +125,9 @@ def resolve_tasks(
                 model_roles=(
                     previous_task.model_roles or loaded_task.model_roles or model_roles
                 ),
-                sandbox=previous_task.log.eval.sandbox,
+                sandbox=resolve_task_file_sandbox(
+                    previous_task.log.eval.task_file, previous_task.log.eval.sandbox
+                ),
                 sequence=sequence,
                 id=previous_task.id,
                 sample_source=eval_log_sample_source(
@@ -216,6 +217,25 @@ def resolve_task_sandbox(
     return resolved_sandbox
 
 
+def resolve_task_file_sandbox(
+    task_file: str | None, sandbox: SandboxEnvironmentSpec | None
+) -> SandboxEnvironmentSpec | None:
+    if sandbox is None or not isinstance(sandbox.config, str):
+        return sandbox
+
+    if task_file is None:
+        return sandbox
+
+    file_path = Path(sandbox.config)
+    if file_path.is_absolute():
+        return sandbox
+
+    # resolve relative sandbox config paths from logged task file location
+    src_dir = Path(task_file).parent
+    file_path = (src_dir / file_path).resolve()
+    return SandboxEnvironmentSpec(sandbox.type, file_path.as_posix())
+
+
 def load_tasks(
     task_specs: list[str] | None, task_args: dict[str, Any] = {}
 ) -> list[Task]:
@@ -333,54 +353,6 @@ def split_spec(spec: str) -> tuple[str, str | None]:
         return spec, None
 
 
-@overload
-def load_module(
-    module_path: Path, filter: Callable[[str], bool]
-) -> ModuleType | None: ...
-
-
-@overload
-def load_module(module_path: Path, filter: None = None) -> ModuleType: ...
-
-
-def load_module(
-    module_path: Path, filter: Callable[[str], bool] | None = None
-) -> ModuleType | None:
-    if module_path.suffix == ".py":
-        # bail if the code doesn't pass the filter
-        with open(module_path, "r", encoding="utf-8") as file:
-            if filter and not filter(file.read()):
-                return None
-
-        module_name = module_path.as_posix()
-        loader = SourceFileLoader(module_name, module_path.absolute().as_posix())
-        spec = spec_from_loader(loader.name, loader)
-        if not spec:
-            raise ModuleNotFoundError(f"Module {module_name} not found")
-        module = module_from_spec(spec)
-        loader.exec_module(module)
-        return module
-
-    elif module_path.suffix == ".ipynb":
-        try:
-            from inspect_ai._util.notebook import NotebookLoader
-        except ImportError:
-            return None
-
-        # bail if the code doesn't pass the filter
-        def exec_filter(cells: list[str]) -> bool:
-            code = "\n\n".join(cells)
-            return not filter or filter(code)
-
-        notebook_loader = NotebookLoader(exec_filter)
-        return notebook_loader.load_module(module_path.as_posix())
-
-    else:
-        raise ModuleNotFoundError(
-            f"Invalid extension for task file: {module_path.suffix}"
-        )
-
-
 def code_has_decorator(code: str, decorator: str) -> bool:
     try:
         tree = ast.parse(code)
