@@ -20,7 +20,8 @@ from inspect_ai.approval._policy import ApprovalPolicy, approval_policies_from_c
 from inspect_ai.dataset import Dataset, MemoryDataset, Sample
 from inspect_ai.log import EvalLog
 from inspect_ai.model import GenerateConfig
-from inspect_ai.model._model import Model, get_model
+from inspect_ai.model._model import Model
+from inspect_ai.model._util import resolve_model, resolve_model_roles
 from inspect_ai.scorer import Metric, Scorer
 from inspect_ai.scorer._reducer import ScoreReducers, create_reducers
 from inspect_ai.solver import Plan, Solver, generate
@@ -57,7 +58,9 @@ class Task:
         solver: Solver | Agent | list[Solver] = generate(),
         cleanup: Callable[[TaskState], Awaitable[None]] | None = None,
         scorer: Scorer | list[Scorer] | None = None,
-        metrics: list[Metric] | dict[str, list[Metric]] | None = None,
+        metrics: list[Metric | dict[str, list[Metric]]]
+        | dict[str, list[Metric]]
+        | None = None,
         model: str | Model | None = None,
         config: GenerateConfig = GenerateConfig(),
         model_roles: dict[str, str | Model] | None = None,
@@ -207,7 +210,10 @@ def task_with(
     solver: Solver | list[Solver] | NotGiven = NOT_GIVEN,
     cleanup: Callable[[TaskState], Awaitable[None]] | None | NotGiven = NOT_GIVEN,
     scorer: Scorer | list[Scorer] | None | NotGiven = NOT_GIVEN,
-    metrics: list[Metric] | dict[str, list[Metric]] | None | NotGiven = NOT_GIVEN,
+    metrics: list[Metric | dict[str, list[Metric]]]
+    | dict[str, list[Metric]]
+    | None
+    | NotGiven = NOT_GIVEN,
     model: str | Model | NotGiven = NOT_GIVEN,
     config: GenerateConfig | NotGiven = NOT_GIVEN,
     model_roles: dict[str, str | Model] | NotGiven = NOT_GIVEN,
@@ -393,28 +399,6 @@ def resolve_solver(solver: Solver | Agent | list[Solver]) -> Solver:
         return cast(Solver, solver)
 
 
-def resolve_model(model: str | Model | None) -> Model | None:
-    if isinstance(model, str):
-        return get_model(model)
-    else:
-        return model
-
-
-def resolve_model_roles(
-    model_roles: dict[str, str | Model] | None,
-) -> dict[str, Model] | None:
-    if model_roles is not None:
-        resolved_model_roles = {
-            k: get_model(v, memoize=False) if isinstance(v, str) else v
-            for k, v in model_roles.items()
-        }
-        for k, v in resolved_model_roles.items():
-            v._set_role(k)
-        return resolved_model_roles
-    else:
-        return None
-
-
 def resolve_scorer(scorer: Scorer | list[Scorer] | None) -> list[Scorer] | None:
     return (
         scorer if isinstance(scorer, list) else [scorer] if scorer is not None else None
@@ -422,7 +406,8 @@ def resolve_scorer(scorer: Scorer | list[Scorer] | None) -> list[Scorer] | None:
 
 
 def resolve_scorer_metrics(
-    scorers: list[Scorer] | None, metrics: list[Metric] | dict[str, list[Metric]] | None
+    scorers: list[Scorer] | None,
+    metrics: list[Metric | dict[str, list[Metric]]] | dict[str, list[Metric]] | None,
 ) -> list[Scorer] | None:
     if scorers is not None and metrics is not None:
         for scorer in scorers:
