@@ -431,6 +431,12 @@ def safe_filename(s: str, max_length: int = 255) -> str:
     return s
 
 
+# clean underscores, slashes, and : from the file name component so we can reliably
+# parse components out later without worrying about underscores
+def clean_filename_component(component: str) -> str:
+    return component.replace("_", "-").replace("/", "-").replace(":", "-")
+
+
 DEFAULT_FS_OPTIONS: dict[str, dict[str, Any]] = dict(
     # disable all S3 native caching
     s3=dict(default_fill_cache=False, default_cache_type="none", cache_regions=False)
