@@ -1,3 +1,4 @@
+import os
 import shutil
 import subprocess
 
@@ -7,9 +8,14 @@ from pydantic import BaseModel
 class GitContext(BaseModel):
     origin: str
     commit: str
+    dirty: bool
 
 
 def git_context() -> GitContext | None:
+    # skip git operations when running under pytest
+    if os.environ.get("PYTEST_CURRENT_TEST"):
+        return None
+
     # check for git
     git = shutil.which("git")
     if not git:
@@ -29,5 +35,13 @@ def git_context() -> GitContext | None:
         text=True,
     ).stdout.strip()
 
+    # check if working tree is dirty
+    status_result = subprocess.run(
+        [git, "status", "--porcelain"],
+        capture_output=True,
+        text=True,
+    )
+    dirty = bool(status_result.stdout.strip())
+
     # return context
-    return GitContext(origin=origin, commit=commit_result.stdout.strip())
+    return GitContext(origin=origin, commit=commit_result.stdout.strip(), dirty=dirty)
