@@ -8,6 +8,7 @@ import {
   useSampleSummaries,
   useTotalSampleCount,
 } from "../../state/hooks";
+import { useUnloadLog } from "../../state/log";
 import { useStore } from "../../state/store";
 import { baseUrl, sampleUrl, useLogRouteParams } from "../routing/url";
 import { LogViewLayout } from "./LogViewLayout";
@@ -28,18 +29,15 @@ export const LogViewContainer: FC = () => {
   const setShowingSampleDialog = useStore(
     (state) => state.appActions.setShowingSampleDialog,
   );
-  const setStatus = useStore((state) => state.appActions.setStatus);
   const setWorkspaceTab = useStore((state) => state.appActions.setWorkspaceTab);
 
-  const refreshLogs = useStore((state) => state.logsActions.refreshLogs);
-  const selectLogFile = useStore((state) => state.logsActions.selectLogFile);
   const selectSample = useStore((state) => state.logActions.selectSample);
-  const setSelectedLogIndex = useStore(
-    (state) => state.logsActions.setSelectedLogIndex,
+  const setSelectedLogFile = useStore(
+    (state) => state.logsActions.setSelectedLogFile,
   );
 
   const clearSelectedLogSummary = useStore(
-    (state) => state.logActions.clearSelectedLogSummary,
+    (state) => state.logActions.clearSelectedLogDetails,
   );
 
   const clearSelectedSample = useStore(
@@ -52,6 +50,16 @@ export const LogViewContainer: FC = () => {
   const sampleSummaries = useSampleSummaries();
   const [searchParams] = useSearchParams();
 
+  // Unload the log when this is mounted. This prevents the old log
+  // data from being displayed when navigating back to the logs panel
+  // and also ensures that we reload logs when freshly navigating to them.
+  const { unloadLog } = useUnloadLog();
+  useEffect(() => {
+    return () => {
+      unloadLog();
+    };
+  }, []);
+
   useEffect(() => {
     // Redirect to an id/epoch url if a sampleUuid is provided
     if (logPath && sampleUuid && sampleSummaries) {
@@ -81,11 +89,13 @@ export const LogViewContainer: FC = () => {
   }, [initialState, evalSpec]);
 
   const prevLogPath = usePrevious<string | undefined>(logPath);
+  const syncLogs = useStore((state) => state.logsActions.syncLogs);
 
   useEffect(() => {
     const loadLogFromPath = async () => {
       if (logPath) {
-        await selectLogFile(logPath);
+        await syncLogs();
+        setSelectedLogFile(logPath);
 
         // Set the tab if specified in the URL
         if (tabId) {
@@ -106,39 +116,21 @@ export const LogViewContainer: FC = () => {
     };
 
     loadLogFromPath();
-  }, [
-    logPath,
-    tabId,
-    selectLogFile,
-    refreshLogs,
-    setWorkspaceTab,
-    setSelectedLogIndex,
-    setStatus,
-  ]);
+  }, [logPath, tabId, setSelectedLogFile, setWorkspaceTab]);
 
   // Handle sample selection from URL params
   useEffect(() => {
     if (sampleId && filteredSamples) {
-      // Find the sample with matching ID and epoch
+      const targetEpoch = epoch ? parseInt(epoch, 10) : 1;
+      selectSample(sampleId, targetEpoch);
 
-      const targetEpoch = epoch ? parseInt(epoch, 10) : undefined;
-      const sampleIndex = filteredSamples.findIndex((sample) => {
-        const matches =
-          String(sample.id) === sampleId &&
-          (targetEpoch === undefined || sample.epoch === targetEpoch);
-        return matches;
-      });
+      // Set the sample tab if specified in the URL
+      if (sampleTabId) {
+        setSampleTab(sampleTabId);
+      }
 
-      if (sampleIndex >= 0) {
-        selectSample(sampleIndex);
-        // Set the sample tab if specified in the URL
-        if (sampleTabId) {
-          setSampleTab(sampleTabId);
-        }
-
-        if (filteredSamples.length > 1) {
-          setShowingSampleDialog(true);
-        }
+      if (filteredSamples.length > 1) {
+        setShowingSampleDialog(true);
       }
     } else {
       // If we don't have sample params in the URL but the dialog is showing, close it
