@@ -2,6 +2,7 @@ import clsx from "clsx";
 import { FC, memo, RefObject, useEffect, useMemo, useRef } from "react";
 import { VirtuosoHandle } from "react-virtuoso";
 import { Events } from "../../../@types/log";
+import { NoContentsPanel } from "../../../components/NoContentsPanel";
 import { StickyScroll } from "../../../components/StickyScroll";
 import { useCollapsedState } from "../../../state/hooks";
 import { useStore } from "../../../state/store";
@@ -10,8 +11,9 @@ import { useLogRouteParams } from "../../routing/url";
 import { TranscriptOutline } from "./outline/TranscriptOutline";
 import styles from "./TranscriptPanel.module.css";
 import { TranscriptVirtualList } from "./TranscriptVirtualList";
+import { flatTree as flattenTree } from "./transform/flatten";
 import { useEventNodes } from "./transform/hooks";
-import { flatTree } from "./transform/treeify";
+import { hasSpans } from "./transform/utils";
 import { kTranscriptCollapseScope } from "./types";
 
 interface TranscriptPanelProps {
@@ -58,7 +60,7 @@ export const TranscriptPanel: FC<TranscriptPanelProps> = memo((props) => {
 
   const flattenedNodes = useMemo(() => {
     // flattten the event tree
-    return flatTree(
+    return flattenTree(
       eventNodes,
       (collapsedEvents
         ? collapsedEvents[kTranscriptCollapseScope]
@@ -68,13 +70,44 @@ export const TranscriptPanel: FC<TranscriptPanelProps> = memo((props) => {
 
   // Update the collapsed events when the default collapsed IDs change
   // This effect only depends on defaultCollapsedIds, not eventNodes
+
+  const collapsedMode = useStore((state) => state.sample.collapsedMode);
+
   useEffect(() => {
-    // Only initialize collapsedEvents if it's empty
+    if (events.length <= 0 || collapsedMode !== null) {
+      return;
+    }
+
     if (!collapsedEvents && Object.keys(defaultCollapsedIds).length > 0) {
       setCollapsedEvents(kTranscriptCollapseScope, defaultCollapsedIds);
     }
   }, [defaultCollapsedIds, collapsedEvents, setCollapsedEvents]);
 
+  const allNodesList = useMemo(() => {
+    return flattenTree(eventNodes, null);
+  }, [eventNodes]);
+
+  useEffect(() => {
+    if (events.length <= 0 || collapsedMode === null) {
+      return;
+    }
+
+    const collapseIds: Record<string, boolean> = {};
+    const collapsed = collapsedMode === "collapsed";
+
+    allNodesList.forEach((node) => {
+      if (
+        node.event.uuid &&
+        ((collapsed && !hasSpans(node.children.map((child) => child.event))) ||
+          !collapsed)
+      ) {
+        collapseIds[node.event.uuid] = collapsedMode === "collapsed";
+      }
+    });
+
+    setCollapsedEvents(kTranscriptCollapseScope, collapseIds);
+  }, [collapsedMode, events, allNodesList]);
+
   const { logPath } = useLogRouteParams();
   const [collapsed, setCollapsed] = useCollapsedState(
     `transcript-panel-${logPath || "na"}`,
@@ -124,42 +157,52 @@ export const TranscriptPanel: FC<TranscriptPanelProps> = memo((props) => {
     }
   }, [scrollRef, flattenedNodes]);
 
-  return (
-    <div
-      className={clsx(
-        styles.container,
-        collapsed ? styles.collapsed : undefined,
-      )}
-    >
-      <StickyScroll
-        scrollRef={scrollRef}
-        className={styles.treeContainer}
-        offsetTop={topOffset}
+  if (flattenedNodes.length === 0) {
+    const isCompletedFiltered =
+      flattenedNodes.length === 0 && events.length > 0;
+    const message = isCompletedFiltered
+      ? "The currently applied filter hides all events."
+      : "No events to display.";
+    return <NoContentsPanel text={message} />;
+  } else {
+    return (
+      <div
+        className={clsx(
+          styles.container,
+          collapsed ? styles.collapsed : undefined,
+        )}
       >
-        <TranscriptOutline
-          className={clsx(styles.outline)}
-          eventNodes={eventNodes}
-          running={running}
-          defaultCollapsedIds={defaultCollapsedIds}
+        <StickyScroll
           scrollRef={scrollRef}
-        />
-        <div
-          className={styles.outlineToggle}
-          onClick={() => setCollapsed(!collapsed)}
+          className={styles.treeContainer}
+          offsetTop={topOffset}
         >
-          <i className={ApplicationIcons.sidebar} />
-        </div>
-      </StickyScroll>
-      <TranscriptVirtualList
-        id={id}
-        listHandle={listHandle}
-        eventNodes={flattenedNodes}
-        scrollRef={scrollRef}
-        running={running}
-        initialEventId={initialEventId === undefined ? null : initialEventId}
-        offsetTop={topOffset}
-        className={styles.listContainer}
-      />
-    </div>
-  );
+          <TranscriptOutline
+            className={clsx(styles.outline)}
+            eventNodes={eventNodes}
+            running={running}
+            defaultCollapsedIds={defaultCollapsedIds}
+            scrollRef={scrollRef}
+          />
+          <div
+            className={styles.outlineToggle}
+            onClick={() => setCollapsed(!collapsed)}
+          >
+            <i className={ApplicationIcons.sidebar} />
+          </div>
+        </StickyScroll>
+
+        <TranscriptVirtualList
+          id={id}
+          listHandle={listHandle}
+          eventNodes={flattenedNodes}
+          scrollRef={scrollRef}
+          running={running}
+          initialEventId={initialEventId === undefined ? null : initialEventId}
+          offsetTop={topOffset}
+          className={styles.listContainer}
+        />
+      </div>
+    );
+  }
 });
