@@ -10,6 +10,7 @@ import {
   SampleLimitEvent,
   SandboxEvent,
   ScoreEvent,
+  ScoreEditEvent,
   SpanBeginEvent,
   SpanEndEvent,
   StateEvent,
@@ -19,6 +20,8 @@ import {
   ToolEvent,
 } from "../../../@types/log";
 
+import { STEP, SPAN_BEGIN, TYPE_TOOL, TYPE_SUBTASK } from "./transform/utils";
+
 export interface StateManager {
   scope: string;
   getState(): object;
@@ -27,6 +30,14 @@ export interface StateManager {
 }
 
 export const kTranscriptCollapseScope = "transcript-collapse";
+export const kTranscriptOutlineCollapseScope = "transcript-outline";
+
+export const kCollapsibleEventTypes = [
+  STEP,
+  SPAN_BEGIN,
+  TYPE_TOOL,
+  TYPE_SUBTASK,
+];
 
 export type EventType =
   | SampleInitEvent
@@ -39,6 +50,7 @@ export type EventType =
   | StepEvent
   | SubtaskEvent
   | ScoreEvent
+  | ScoreEditEvent
   | ToolEvent
   | InputEvent
   | ErrorEvent
