@@ -1,20 +1,32 @@
+import clsx from "clsx";
 import { ButtonHTMLAttributes, forwardRef, ReactNode } from "react";
-import "./ToolButton.css";
+import styles from "./ToolButton.module.css";
 
 interface ToolButtonProps extends ButtonHTMLAttributes<HTMLButtonElement> {
   label: string | ReactNode;
   classes?: string;
   icon?: string;
+  latched?: boolean;
 }
 
 export const ToolButton = forwardRef<HTMLButtonElement, ToolButtonProps>(
-  ({ label, classes = "", icon, className, ...rest }, ref) => {
+  ({ label, classes = "", icon, className, latched, ...rest }, ref) => {
     // Combine class names, ensuring default classes are applied first
-    const combinedClasses =
-      `btn btn-tools tool-button ${classes} ${className || ""}`.trim();
 
     return (
-      <button ref={ref} type="button" className={combinedClasses} {...rest}>
+      <button
+        ref={ref}
+        type="button"
+        className={clsx(
+          "btn",
+          "btn-tools",
+          styles.toolButton,
+          classes,
+          className,
+          latched ? styles.latched : undefined,
+        )}
+        {...rest}
+      >
         {icon && <i className={`${icon}`} />}
         {label}
       </button>
