@@ -3,6 +3,7 @@ from typing import Awaitable, Callable, NamedTuple, TypeAlias
 from inspect_ai.agent._agent import AgentState
 from inspect_ai.scorer._metric import Score, ValueToFloat, value_to_float
 from inspect_ai.tool._tool import Tool
+from inspect_ai.tool._tool_def import ToolDef
 
 DEFAULT_HANDOFF_PROMPT = """
 You are part of a multi-agent system designed to make agent coordination and
@@ -104,7 +105,7 @@ class AgentSubmit(NamedTuple):
     description: str | None = None
     """Description of submit tool (defaults to 'Submit an answer for evaluation')."""
 
-    tool: Tool | None = None
+    tool: Tool | ToolDef | None = None
     """Alternate implementation for submit tool.
 
     The tool can provide its `name` and `description` internally,
