@@ -227,7 +227,6 @@ def write_log_dir_manifest(
     names = [manifest_eval_log_name(log, log_dir, fs.sep) for log in logs]
     headers = read_eval_log_headers(logs)
 
-    headers[0].reductions = None
     manifest_logs = dict(zip(names, headers))
 
     # form target path and write
@@ -251,7 +250,7 @@ def read_eval_log(
        log_file (str | FileInfo): Log file to read.
        header_only (bool): Read only the header (i.e. exclude
           the "samples" and "logging" fields). Defaults to False.
-       resolve_attachments (bool): Resolve attachments (e.g. images)
+       resolve_attachments (bool): Resolve attachments (duplicated content blocks)
           to their full content.
        format (Literal["eval", "json", "auto"]): Read from format
           (defaults to 'auto' based on `log_file` extension)
@@ -289,7 +288,7 @@ async def read_eval_log_async(
        log_file (str | FileInfo): Log file to read.
        header_only (bool): Read only the header (i.e. exclude
           the "samples" and "logging" fields). Defaults to False.
-       resolve_attachments (bool): Resolve attachments (e.g. images)
+       resolve_attachments (bool): Resolve attachments (duplicated content blocks)
           to their full content.
        format (Literal["eval", "json", "auto"]): Read from format
           (defaults to 'auto' based on `log_file` extension)
@@ -364,7 +363,7 @@ def read_eval_log_sample(
        epoch (int): Epoch for sample id (defaults to 1)
        uuid: Sample uuid to read. Optional, alternatively specify
          `id` and `epoch` (you must specify either `uuid` or `id`)
-       resolve_attachments (bool): Resolve attachments (e.g. images)
+       resolve_attachments (bool): Resolve attachments (duplicated content blocks)
           to their full content.
        format (Literal["eval", "json", "auto"]): Read from format
           (defaults to 'auto' based on `log_file` extension)
@@ -405,7 +404,7 @@ async def read_eval_log_sample_async(
        id (int | str): Sample id to read.
        epoch (int): Epoch for sample id (defaults to 1)
        uuid: Sample uuid to read.
-       resolve_attachments (bool): Resolve attachments (e.g. images)
+       resolve_attachments (bool): Resolve attachments (duplicated content blocks)
           to their full content.
        format (Literal["eval", "json", "auto"]): Read from format
           (defaults to 'auto' based on `log_file` extension)
@@ -513,7 +512,7 @@ def read_eval_log_samples(
        log_file (str | FileInfo): Log file to read.
        all_samples_required (bool): All samples must be included in
           the file or an IndexError is thrown.
-       resolve_attachments (bool): Resolve attachments (e.g. images)
+       resolve_attachments (bool): Resolve attachments (duplicated content blocks)
           to their full content.
        format (Literal["eval", "json", "auto"]): Read from format
           (defaults to 'auto' based on `log_file` extension)
