@@ -11,7 +11,8 @@ from inspect_ai.util._limit import LimitExceededError
 from inspect_ai.util._sandbox import SandboxConnection
 from inspect_ai.util._sandbox.context import sandbox_connections
 
-from ._transcript import ModelEvent, Transcript
+from ..event._model import ModelEvent
+from ._transcript import Transcript
 
 
 class ActiveSample:
@@ -191,6 +192,10 @@ def track_active_model_event(event: ModelEvent) -> Iterator[None]:
         _active_model_event.reset(token)
 
 
+def has_active_model_event() -> bool:
+    return _active_model_event.get() is not None
+
+
 def report_active_sample_retry() -> None:
     model_event = _active_model_event.get()
     if model_event is not None:
