@@ -15,12 +15,14 @@ from typing import (
     Awaitable,
     Callable,
     Literal,
+    NamedTuple,
     Sequence,
     Type,
     TypeAlias,
     cast,
 )
 
+import anyio
 from pydantic import BaseModel
 from pydantic_core import to_jsonable_python
 from tenacity import (
@@ -64,7 +66,7 @@ from inspect_ai.util._limit import (
     record_model_usage,
 )
 
-from ._cache import CacheEntry, CachePolicy, cache_fetch, cache_store
+from ._cache import CacheEntry, CachePolicy, cache_fetch, cache_store, epoch
 from ._call_tools import (
     disable_parallel_tools,
     execute_tools,
@@ -94,14 +96,31 @@ from ._model_output import ModelOutput, ModelUsage
 
 logger = logging.getLogger(__name__)
 
+
+class GenerateInput(NamedTuple):
+    """Input parameters for generate function."""
+
+    input: list[ChatMessage]
+    """Chat message input."""
+
+    tools: list[ToolInfo]
+    """Tools available for the model to call."""
+
+    tool_choice: ToolChoice | None
+    """Directives to the model as to which tools to prefer."""
+
+    config: GenerateConfig
+    """Model configuration."""
+
+
 GenerateFilter: TypeAlias = Callable[
     [str, list[ChatMessage], list[ToolInfo], ToolChoice | None, GenerateConfig],
-    Awaitable[ModelOutput | None],
+    Awaitable[ModelOutput | GenerateInput | None],
 ]
 """Filter a model generation.
 
 A filter may substitute for the default model generation by returning a
-`ModelOutput` or return `None` to allow default processing to continue.
+`ModelOutput`, modify the input parameters by returning a `GenerateInput`, or return `None` to allow default processing to continue.
 """
 
 
@@ -137,11 +156,16 @@ class ModelAPI(abc.ABC):
         """
         self.model_name = model_name
         self.base_url = base_url
+        self.api_key = api_key
+        self.api_key_vars = api_key_vars
+        self._apply_api_key_overrides()
 
+    def _apply_api_key_overrides(self) -> None:
         from inspect_ai.hooks._hooks import override_api_key
 
         # apply api key override
-        for key in api_key_vars:
+        api_key = self.api_key
+        for key in self.api_key_vars:
             # if there is an explicit api_key passed then it
             # overrides anything in the environment so use it
             if api_key is not None:
@@ -160,6 +184,13 @@ class ModelAPI(abc.ABC):
         # set any explicitly specified api key
         self.api_key = api_key
 
+    def initialize(self) -> None:
+        """Reinitialize the model API client.
+
+        This can be used to reinitialize the API keys.
+        """
+        self._apply_api_key_overrides()
+
     async def aclose(self) -> None:
         """Async close method for closing any client allocated for the model."""
         self.close()
@@ -175,6 +206,10 @@ class ModelAPI(abc.ABC):
                 f"{self.__class__.__name__} models require an async close / context manager."
             )
 
+    def canonical_name(self) -> str:
+        """Canonical model name for querying results."""
+        return self.model_name
+
     @abc.abstractmethod
     async def generate(
         self,
@@ -186,14 +221,10 @@ class ModelAPI(abc.ABC):
         """Generate output from the model.
 
         Args:
-          input (str | list[ChatMessage]): Chat message
-            input (if a `str` is passed it is converted
-            to a `ChatUserMessage`).
-          tools (list[ToolInfo]): Tools available for the
-            model to call.
-          tool_choice (ToolChoice): Directives to the model
-            as to which tools to prefer.
-          config (GenerateConfig): Model configuration.
+          input: Chat message input (if a `str` is passed it is converted to a `ChatUserMessage`).
+          tools: Tools available for the model to call.
+          tool_choice: Directives to the model as to which tools to prefer.
+          config: Model configuration.
 
         Returns:
            ModelOutput or tuple[ModelOutput,ModelCall], the latter being
@@ -233,6 +264,17 @@ class ModelAPI(abc.ABC):
         """
         return False
 
+    def is_auth_failure(self, ex: Exception) -> bool:
+        """Check if this exception indicates an authentication failure.
+
+        Args:
+           ex: Exception to check for authentication failure
+
+        Returns:
+           True if this is an authentication error (e.g., 401 Unauthorized)
+        """
+        return False
+
     def collapse_user_messages(self) -> bool:
         """Collapse consecutive user messages into a single message."""
         return False
@@ -290,7 +332,10 @@ class Model:
     """Generation config."""
 
     def __init__(
-        self, api: ModelAPI, config: GenerateConfig, model_args: dict[str, Any] = {}
+        self,
+        api: ModelAPI,
+        config: GenerateConfig,
+        model_args: dict[str, Any] | None = None,
     ) -> None:
         """Create a model.
 
@@ -301,7 +346,7 @@ class Model:
         """
         self.api = api
         self.config = config
-        self.model_args = model_args
+        self.model_args = model_args if model_args is not None else {}
         self._role: str | None = None
 
         # state indicating whether our lifetime is bound by a context manager
@@ -376,6 +421,14 @@ class Model:
         Returns:
            ModelOutput
         """
+        # if we have a TaskState then update the epoch. without this, it's possible
+        # we'd cache the same response for every single epoch
+        from inspect_ai.solver._task_state import sample_state
+
+        state = sample_state()
+        if state is not None:
+            epoch.set(state.epoch)
+
         # if we are the default model then update the displayed message count
         is_active_model = self == active_model()
         if is_active_model:
@@ -443,7 +496,7 @@ class Model:
             # created _after_ the call to _generate, potentially in response
             # to retries, so they need their timestamp updated so it accurately
             # reflects the full start/end time which we know here)
-            from inspect_ai.log._transcript import ModelEvent
+            from inspect_ai.event._model import ModelEvent
 
             assert isinstance(event, ModelEvent)
             event.timestamp = start_time
@@ -516,10 +569,10 @@ class Model:
         config: GenerateConfig,
         cache: bool | CachePolicy = False,
     ) -> tuple[ModelOutput, BaseModel]:
-        from inspect_ai.hooks._hooks import emit_model_usage
+        from inspect_ai.event._model import ModelEvent
+        from inspect_ai.hooks._hooks import emit_model_cache_usage, emit_model_usage
         from inspect_ai.hooks._legacy import send_telemetry_legacy
         from inspect_ai.log._samples import track_active_model_event
-        from inspect_ai.log._transcript import ModelEvent
 
         # default to 'auto' for tool_choice (same as underlying model apis)
         tool_choice = tool_choice if tool_choice is not None else "auto"
@@ -602,6 +655,7 @@ class Model:
                 config.max_retries,
                 config.timeout,
                 self.should_retry,
+                self.before_retry,
                 log_model_retry,
             )
         )
@@ -636,6 +690,10 @@ class Model:
                         output=existing,
                         call=None,
                     )
+                    if existing.usage:
+                        await emit_model_cache_usage(
+                            model_name=str(self), usage=existing.usage
+                        )
                     return existing, event
             else:
                 cache_entry = None
@@ -653,17 +711,31 @@ class Model:
                 cache="write" if cache else None,
             )
 
+            # create timeout context manager if we have an attempt timeout
+            timeout_cm = (
+                anyio.move_on_after(config.attempt_timeout)
+                if config.attempt_timeout is not None
+                else contextlib.nullcontext()
+            )
+
             with trace_action(logger, "Model", f"generate ({str(self)})"):
                 time_start = time.monotonic()
                 try:
                     assert isinstance(event, ModelEvent)
                     with track_active_model_event(event):
-                        result = await self.api.generate(
-                            input=input,
-                            tools=tools_info,
-                            tool_choice=tool_choice,
-                            config=config,
-                        )
+                        with timeout_cm:
+                            result = await self.api.generate(
+                                input=input,
+                                tools=tools_info,
+                                tool_choice=tool_choice,
+                                config=config,
+                            )
+                        if (
+                            isinstance(timeout_cm, anyio.CancelScope)
+                            and timeout_cm.cancel_called
+                        ):
+                            raise AttemptTimeoutError(config.attempt_timeout)
+
                 finally:
                     time_elapsed = time.monotonic() - time_start
 
@@ -731,6 +803,11 @@ class Model:
 
     def should_retry(self, ex: BaseException) -> bool:
         if isinstance(ex, Exception):
+            # attempt timeout is always retried (we rely on `timeout`
+            # and/or `max_retries` for termination)
+            if isinstance(ex, AttemptTimeoutError):
+                return True
+
             # check standard should_retry() method
             retry = self.api.should_retry(ex)
             if retry:
@@ -753,6 +830,13 @@ class Model:
         # no retry
         return False
 
+    async def before_retry(self, ex: BaseException) -> None:
+        if isinstance(ex, Exception) and self.api.is_auth_failure(ex):
+            # close existing model instance
+            await self.api.aclose()
+            # re-initialize
+            self.api.initialize()
+
     # function to verify that its okay to call model apis
     def verify_model_apis(self) -> None:
         if (
@@ -802,7 +886,8 @@ class Model:
         output: ModelOutput | None = None,
         call: ModelCall | None = None,
     ) -> tuple[Callable[[ModelOutput | Exception, ModelCall | None], None], BaseModel]:
-        from inspect_ai.log._transcript import ModelEvent, transcript
+        from inspect_ai.event._model import ModelEvent
+        from inspect_ai.log._transcript import transcript
 
         # create event and add it to the transcript
         model = str(self)
@@ -844,6 +929,11 @@ class Model:
         return complete, event
 
 
+class AttemptTimeoutError(RuntimeError):
+    def __init__(self, timeout: int | None) -> None:
+        super().__init__(f"attempt_timeout '{timeout or 0}' exceeded.")
+
+
 class ModelName:
     r"""Model name (api and specific model served by the api).
 
@@ -988,7 +1078,9 @@ def get_model(
         if model is not None:
             model = model.split(",")[0]
         else:
-            raise ValueError("No model specified (and no INSPECT_EVAL_MODEL defined)")
+            raise ValueError(
+                "No model specified (and no model environment varible defined)"
+            )
 
     # see if we can return a memoized model instance
     # (exclude mockllm since custom_outputs is an infinite generator)
