@@ -147,7 +147,14 @@ def _get_individual_result(
                 error_class = anthropic.InternalServerError
         response = error_class(
             message=message,
-            response=httpx.Response(status_code=500, text=message),
+            response=httpx.Response(
+                status_code=500,
+                text=message,
+                request=httpx.Request(
+                    method="POST",
+                    url="https://api.anthropic.com/v1/messages/batches",
+                ),
+            ),
             body=None,
         )
         response.response.status_code = response.status_code
