@@ -47,6 +47,11 @@ from anthropic.types import (
     TextBlockParam,
     ThinkingBlock,
     ThinkingBlockParam,
+    ToolChoiceAnyParam,
+    ToolChoiceAutoParam,
+    ToolChoiceNoneParam,
+    ToolChoiceParam,
+    ToolChoiceToolParam,
     ToolParam,
     ToolResultBlockParam,
     ToolTextEditor20250124Param,
@@ -59,7 +64,6 @@ from anthropic.types import (
     WebSearchToolResultBlock,
     WebSearchToolResultBlockParam,
     WebSearchToolResultError,
-    message_create_params,
 )
 from anthropic.types.beta import (
     BetaMCPToolResultBlock,
@@ -72,6 +76,7 @@ from anthropic.types.beta import (
     BetaToolComputerUse20250124Param,
     BetaToolTextEditor20241022Param,
     BetaToolTextEditor20250429Param,
+    BetaToolTextEditor20250728Param,
 )
 from anthropic.types.document_block_param import Source
 from anthropic.types.web_search_tool_result_block_param_content_param import (
@@ -168,10 +173,16 @@ class AnthropicAPI(ModelAPI):
             config=config,
         )
 
-        # create client
+        self.model_args = model_args
+        self.initialize()
+
+    def _create_client(
+        self,
+    ) -> AsyncAnthropic | AsyncAnthropicBedrock | AsyncAnthropicVertex:
         if self.is_bedrock():
             base_url = model_base_url(
-                base_url, ["ANTHROPIC_BEDROCK_BASE_URL", "BEDROCK_ANTHROPIC_BASE_URL"]
+                self.base_url,
+                ["ANTHROPIC_BEDROCK_BASE_URL", "BEDROCK_ANTHROPIC_BASE_URL"],
             )
 
             # resolve the default region
@@ -180,24 +191,23 @@ class AnthropicAPI(ModelAPI):
             if base_region is None:
                 aws_region = os.environ.get("AWS_DEFAULT_REGION", None)
 
-            self.client: (
-                AsyncAnthropic | AsyncAnthropicBedrock | AsyncAnthropicVertex
-            ) = AsyncAnthropicBedrock(
+            return AsyncAnthropicBedrock(
                 base_url=base_url,
                 aws_region=aws_region,
-                **model_args,
+                **self.model_args,
             )
         elif self.is_vertex():
             base_url = model_base_url(
-                base_url, ["ANTHROPIC_VERTEX_BASE_URL", "VERTEX_ANTHROPIC_BASE_URL"]
+                self.base_url,
+                ["ANTHROPIC_VERTEX_BASE_URL", "VERTEX_ANTHROPIC_BASE_URL"],
             )
             region = os.environ.get("ANTHROPIC_VERTEX_REGION", NotGiven())
             project_id = os.environ.get("ANTHROPIC_VERTEX_PROJECT_ID", NotGiven())
-            self.client = AsyncAnthropicVertex(
+            return AsyncAnthropicVertex(
                 region=region,
                 project_id=project_id,
                 base_url=base_url,
-                **model_args,
+                **self.model_args,
             )
         else:
             # resolve api_key
@@ -205,17 +215,19 @@ class AnthropicAPI(ModelAPI):
                 self.api_key = os.environ.get(ANTHROPIC_API_KEY, None)
             if self.api_key is None:
                 raise environment_prerequisite_error("Anthropic", ANTHROPIC_API_KEY)
-            base_url = model_base_url(base_url, "ANTHROPIC_BASE_URL")
-            self.client = AsyncAnthropic(
+            base_url = model_base_url(self.base_url, "ANTHROPIC_BASE_URL")
+            return AsyncAnthropic(
                 base_url=base_url,
                 api_key=self.api_key,
-                **model_args,
+                **self.model_args,
             )
 
-        self._batcher: AnthropicBatcher | None = None
-
-        # create time tracker
+    @override
+    def initialize(self) -> None:
+        super().initialize()
+        self.client = self._create_client()
         self._http_hooks = HttpxHooks(self.client._client)
+        self._batcher: AnthropicBatcher | None = None
 
     @override
     async def aclose(self) -> None:
@@ -266,7 +278,7 @@ class AnthropicAPI(ModelAPI):
                 request["system"] = system_param
             request["tools"] = tools_param
             if len(tools_param) > 0 and not self.is_using_thinking(config):
-                request["tool_choice"] = message_tool_choice(tool_choice)
+                request["tool_choice"] = message_tool_choice(tool_choice, config)
 
             # additional options
             req, headers, betas = self.completion_config(config)
@@ -359,6 +371,7 @@ class AnthropicAPI(ModelAPI):
                         config.max_retries,
                         config.timeout,
                         self.should_retry,
+                        lambda ex: None,
                         log_model_retry,
                     ),
                 )
@@ -450,11 +463,17 @@ class AnthropicAPI(ModelAPI):
 
     @override
     def max_tokens(self) -> int | None:
-        # anthropic requires you to explicitly specify max_tokens (most others
+        # Anthropic requires you to explicitly specify max_tokens (most others
         # set it to the maximum allowable output tokens for the model).
-        # set to 4096 which is the highest possible for claude 3 (claude 3.5
-        # allows up to 8192)
-        return 4096
+        # Claude 4 models currently have maxes of 32k (Opus 4 and 4.1) or
+        # 64k (Sonnet 4 and 4.5 and Haiku 4.5). Claude 3 models max at 4k or
+        # 8k, w/ 3.7 Sonnet being capable of 128k w/ a special header).
+        # Therefore, we use 4k as the default for Claude 3 and 32,000 as the
+        # default for everything else.
+        if self.is_claude_3():
+            return 4096
+        else:
+            return 32000
 
     @override
     def max_tokens_for_config(self, config: GenerateConfig) -> int | None:
@@ -485,7 +504,10 @@ class AnthropicAPI(ModelAPI):
         return "claude-3-7-" in self.service_model_name()
 
     def is_claude_4(self) -> bool:
-        return re.search(r"claude-4-[a-zA-Z]", self.service_model_name()) is not None
+        return re.search(r"claude-[a-zA-Z]+-4", self.service_model_name()) is not None
+
+    def is_claude_4_5(self) -> bool:
+        return re.search(r"claude-[a-zA-Z]+-4-5", self.service_model_name()) is not None
 
     @override
     def connection_key(self) -> str:
@@ -495,13 +517,17 @@ class AnthropicAPI(ModelAPI):
         """Model name without any service prefix."""
         return self.model_name.replace(f"{self.service}/", "", 1)
 
+    def canonical_name(self) -> str:
+        return self.service_model_name()
+
     @override
     def should_retry(self, ex: BaseException) -> bool:
         if isinstance(ex, APIStatusError):
             # when streaming, anthropic does not set status_code == 529
-            # for overloaded errors so we check for it explicitly
+            # for overloaded or internal server errors so we check for them explicitly
             if isinstance(ex.body, dict):
-                if "overloaded" in str(ex.body).lower():
+                body_str = str(ex.body).lower()
+                if "overloaded" in body_str or "internal server error" in body_str:
                     return True
 
             # standard http status code checking
@@ -513,6 +539,12 @@ class AnthropicAPI(ModelAPI):
         else:
             return False
 
+    @override
+    def is_auth_failure(self, ex: Exception) -> bool:
+        if isinstance(ex, APIStatusError):
+            return ex.status_code == 401
+        return False
+
     @override
     def collapse_user_messages(self) -> bool:
         return True
@@ -773,6 +805,7 @@ class AnthropicAPI(ModelAPI):
         ToolTextEditor20250124Param
         | BetaToolTextEditor20241022Param
         | BetaToolTextEditor20250429Param
+        | BetaToolTextEditor20250728Param
         | None
     ):
         # See: https://docs.anthropic.com/en/docs/agents-and-tools/tool-use/text-editor-tool#before-using-the-text-editor-tool
@@ -796,7 +829,11 @@ class AnthropicAPI(ModelAPI):
             )
         ):
             return (
-                BetaToolTextEditor20250429Param(
+                BetaToolTextEditor20250728Param(
+                    type="text_editor_20250728", name="str_replace_based_edit_tool"
+                )
+                if self.is_claude_4_5()
+                else BetaToolTextEditor20250429Param(
                     type="text_editor_20250429", name="str_replace_based_edit_tool"
                 )
                 if self.is_claude_4()
@@ -873,6 +910,7 @@ ToolParamDef = (
     | ToolTextEditor20250124Param
     | BetaToolTextEditor20241022Param
     | BetaToolTextEditor20250429Param
+    | BetaToolTextEditor20250728Param
     | WebSearchTool20250305Param
 )
 
@@ -887,6 +925,7 @@ def is_text_editor_tool(
     ToolTextEditor20250124Param
     | BetaToolTextEditor20241022Param
     | BetaToolTextEditor20250429Param
+    | BetaToolTextEditor20250728Param
 ]:
     type = param.get("type", None)
     if type is not None:
@@ -912,6 +951,7 @@ def add_cache_control(
     | ToolTextEditor20250124Param
     | BetaToolTextEditor20241022Param
     | BetaToolTextEditor20250429Param
+    | BetaToolTextEditor20250728Param
     | WebSearchTool20250305Param
     | dict[str, Any],
 ) -> None:
@@ -958,15 +998,32 @@ def combine_messages(a: MessageParam, b: MessageParam) -> MessageParam:
         raise ValueError(f"Unexpected content types for messages: {a}, {b}")
 
 
-def message_tool_choice(tool_choice: ToolChoice) -> message_create_params.ToolChoice:
+def message_tool_choice(
+    tool_choice: ToolChoice, config: GenerateConfig
+) -> ToolChoiceParam:
+    # carve out "none" (it doesn't support disable_parallel_tool_use)
+    if tool_choice == "none":
+        return ToolChoiceNoneParam(type="none")
+
+    # determine tool_choice_param
     if isinstance(tool_choice, ToolFunction):
-        return {"type": "tool", "name": tool_choice.name}
+        tool_choice_param: (
+            ToolChoiceToolParam | ToolChoiceAnyParam | ToolChoiceAutoParam
+        ) = ToolChoiceToolParam(
+            type="tool",
+            name=tool_choice.name,
+        )
     elif tool_choice == "any":
-        return {"type": "any"}
-    elif tool_choice == "none":
-        return {"type": "none"}
+        tool_choice_param = ToolChoiceAnyParam(type="any")
     else:
-        return {"type": "auto"}
+        tool_choice_param = ToolChoiceAutoParam(type="auto")
+
+    # set parallel_tool_calls if specified
+    if config.parallel_tool_calls is not None:
+        tool_choice_param["disable_parallel_tool_use"] = not config.parallel_tool_calls
+
+    # return
+    return tool_choice_param
 
 
 async def message_param(message: ChatMessage) -> MessageParam:
