@@ -30,6 +30,7 @@ from google.genai.types import (
     HarmBlockThreshold,
     HarmCategory,
     HttpOptions,
+    Image,
     Part,
     SafetySetting,
     SafetySettingDict,
@@ -62,6 +63,7 @@ from inspect_ai._util.error import PrerequisiteError
 from inspect_ai._util.http import is_retryable_http_status
 from inspect_ai._util.images import file_as_data
 from inspect_ai._util.kvstore import inspect_kvstore
+from inspect_ai._util.logger import warn_once
 from inspect_ai._util.trace import trace_message
 from inspect_ai.model import (
     ChatCompletionChoice,
@@ -258,92 +260,109 @@ class GoogleGenAIAPI(ModelAPI):
         if config.timeout:
             http_options.timeout = config.timeout * 1000
 
-        # create client
+        # resolve batcher as required
+        self._resolve_batcher(config, http_options)
+
+        # create client and manage its lifetime to this call
         client = Client(
             vertexai=self.is_vertex(),
             api_key=self.api_key,
             http_options=http_options,
             **self.model_args,
         )
+        async with client.aio:
+            # create hooks and allocate request
+            http_hooks = HttpxHooks(client._api_client._async_httpx_client)
+            request_id = http_hooks.start_request()
 
-        self._resolve_batcher(config, client)
-        # create hooks and allocate request
-        http_hooks = HttpxHooks(client._api_client._async_httpx_client)
-        request_id = http_hooks.start_request()
-
-        # Create google-genai types.
-        gemini_contents = await as_chat_messages(client, input)
-        gemini_tools = self.chat_tools(tools) if len(tools) > 0 else None
-        gemini_tool_config = chat_tool_config(tool_choice) if len(tools) > 0 else None
-        parameters = GenerateContentConfig(
-            http_options=HttpOptions(headers={HttpHooks.REQUEST_ID_HEADER: request_id}),
-            temperature=config.temperature,
-            top_p=config.top_p,
-            top_k=config.top_k,
-            max_output_tokens=config.max_tokens,
-            stop_sequences=config.stop_seqs,
-            candidate_count=config.num_choices,
-            presence_penalty=config.presence_penalty,
-            frequency_penalty=config.frequency_penalty,
-            safety_settings=safety_settings_to_list(self.safety_settings),
-            tools=gemini_tools,
-            tool_config=gemini_tool_config,
-            system_instruction=await extract_system_message_as_parts(client, input),  # type: ignore[arg-type]
-            thinking_config=self.chat_thinking_config(config),
-        )
-        if config.response_schema is not None:
-            parameters.response_mime_type = "application/json"
-            parameters.response_schema = schema_from_param(
-                config.response_schema.json_schema, nullable=None
+            # Create google-genai types.
+            gemini_contents = await as_chat_messages(client, input)
+            has_native_search, gemini_tools = (
+                self.chat_tools(tools) if len(tools) > 0 else (False, None)
             )
-
-        response: GenerateContentResponse | None = None
-
-        def model_call() -> ModelCall:
-            return build_model_call(
-                contents=gemini_contents,  # type: ignore[arg-type]
-                safety_settings=self.safety_settings,
-                generation_config=parameters,
+            gemini_tool_config = (
+                chat_tool_config(tool_choice)
+                if not has_native_search and len(tools) > 0
+                else None
+            )
+            system_instruction = await extract_system_message_as_parts(client, input)
+            parameters = GenerateContentConfig(
+                http_options=HttpOptions(
+                    headers={HttpHooks.REQUEST_ID_HEADER: request_id}
+                ),
+                temperature=config.temperature,
+                top_p=config.top_p,
+                top_k=config.top_k,
+                max_output_tokens=config.max_tokens,
+                stop_sequences=config.stop_seqs,
+                candidate_count=config.num_choices,
+                presence_penalty=config.presence_penalty,
+                frequency_penalty=config.frequency_penalty,
+                response_logprobs=config.logprobs,
+                logprobs=config.top_logprobs,
+                safety_settings=safety_settings_to_list(self.safety_settings),
                 tools=gemini_tools,
                 tool_config=gemini_tool_config,
-                response=response,
-                time=http_hooks.end_request(request_id),
+                system_instruction=system_instruction,  # type: ignore[arg-type]
+                thinking_config=self.chat_thinking_config(config),
             )
-
-        try:
-            response = await (
-                self._batcher.generate_for_request(
-                    {
-                        "contents": [
-                            content.model_dump(exclude_none=True)
-                            for content in gemini_contents
-                        ],
-                        **parameters.model_dump(exclude_none=True),
-                    }
+            if config.response_schema is not None:
+                parameters.response_mime_type = "application/json"
+                parameters.response_schema = schema_from_param(
+                    config.response_schema.json_schema, nullable=None
                 )
-                if self._batcher
-                else client.aio.models.generate_content(
-                    model=self.service_model_name(),
+
+            response: GenerateContentResponse | None = None
+
+            def model_call() -> ModelCall:
+                return build_model_call(
                     contents=gemini_contents,  # type: ignore[arg-type]
-                    config=parameters,
+                    safety_settings=self.safety_settings,
+                    generation_config=parameters,
+                    tools=gemini_tools,
+                    tool_config=gemini_tool_config,
+                    system_instruction=system_instruction,
+                    response=response,
+                    time=http_hooks.end_request(request_id),
                 )
+
+            try:
+                response = await (
+                    self._batcher.generate_for_request(
+                        {
+                            "contents": [
+                                content.model_dump(exclude_none=True)
+                                for content in gemini_contents
+                            ],
+                            **parameters.model_dump(exclude_none=True),
+                        }
+                    )
+                    if self._batcher
+                    else client.aio.models.generate_content(
+                        model=self.service_model_name(),
+                        contents=gemini_contents,  # type: ignore[arg-type]
+                        config=parameters,
+                    )
+                )
+            except ClientError as ex:
+                return self.handle_client_error(ex), model_call()
+
+            model_name = response.model_version or self.service_model_name()
+            output = ModelOutput(
+                model=model_name,
+                choices=completion_choices_from_candidates(model_name, response),
+                usage=usage_metadata_to_model_usage(response.usage_metadata),
             )
-        except ClientError as ex:
-            return self.handle_client_error(ex), model_call()
 
-        model_name = response.model_version or self.service_model_name()
-        output = ModelOutput(
-            model=model_name,
-            choices=completion_choices_from_candidates(model_name, response),
-            usage=usage_metadata_to_model_usage(response.usage_metadata),
-        )
-
-        return output, model_call()
+            return output, model_call()
 
     def service_model_name(self) -> str:
         """Model name without any service prefix."""
         return self.model_name.replace(f"{self.service}/", "", 1)
 
+    def canonical_name(self) -> str:
+        return self.service_model_name()
+
     def is_gemini(self) -> bool:
         return "gemini-" in self.service_model_name()
 
@@ -353,6 +372,12 @@ class GoogleGenAIAPI(ModelAPI):
     def is_gemini_2_0(self) -> bool:
         return "gemini-2.0" in self.service_model_name()
 
+    def is_gemini_2_5(self) -> bool:
+        return "gemini-2.5" in self.service_model_name()
+
+    def is_gemini_thinking_only(self) -> bool:
+        return self.is_gemini_2_5() and "-pro" in self.service_model_name()
+
     @override
     def should_retry(self, ex: BaseException) -> bool:
         if isinstance(ex, APIError) and ex.code is not None:
@@ -365,6 +390,12 @@ class GoogleGenAIAPI(ModelAPI):
         """Scope for enforcing max_connections."""
         return str(self.api_key)
 
+    @override
+    def is_auth_failure(self, ex: Exception) -> bool:
+        if isinstance(ex, APIError):
+            return ex.code == 401
+        return False
+
     def handle_client_error(self, ex: ClientError) -> ModelOutput | Exception:
         if (
             ex.code == 400
@@ -389,14 +420,23 @@ class GoogleGenAIAPI(ModelAPI):
         )
         if has_thinking_config:
             if config.reasoning_tokens == 0:
-                # When reasoning_tokens is set to zero, we disable reasoning and return None.
-                # We cannot return a ThinkingConfig with reasoning_tokens set to 0,
-                # as this will cause the Gemini API to return a 400 INVALID_ARGUMENT error.
-                return None
-
-            return ThinkingConfig(
-                include_thoughts=True, thinking_budget=config.reasoning_tokens
-            )
+                if self.is_gemini_thinking_only():
+                    # When reasoning_tokens is set to 0 and it's a thinking only model we don't
+                    # bother trying to shut down thining as this is not possible:
+                    #   https://ai.google.dev/gemini-api/docs/thinking#set-budget
+                    # warn and return include_thoughts=True so the user sees what is happening
+                    warn_once(
+                        logger,
+                        f"Thinking cannot be disabled for model {self.service_model_name()}.",
+                    )
+                    return ThinkingConfig(include_thoughts=True)
+                else:
+                    # otherwise do the disable
+                    return ThinkingConfig(include_thoughts=False, thinking_budget=0)
+            else:
+                return ThinkingConfig(
+                    include_thoughts=True, thinking_budget=config.reasoning_tokens
+                )
         else:
             return None
 
@@ -437,7 +477,7 @@ class GoogleGenAIAPI(ModelAPI):
             )
         )
 
-    def chat_tools(self, tools: list[ToolInfo]) -> ToolListUnion:
+    def chat_tools(self, tools: list[ToolInfo]) -> tuple[bool, ToolListUnion]:
         has_native_search, function_declarations = functools.reduce(
             self._categorize_tool, tools, (False, list[FunctionDeclaration]())
         )
@@ -450,14 +490,25 @@ class GoogleGenAIAPI(ModelAPI):
             )
 
         return (
-            [Tool(google_search=GoogleSearch())]
+            (True, [Tool(google_search=GoogleSearch())])
             if has_native_search
-            else [Tool(function_declarations=function_declarations)]
+            else (False, [Tool(function_declarations=function_declarations)])
         )
 
-    def _resolve_batcher(self, config: GenerateConfig, client: Client) -> None:
+    def _resolve_batcher(
+        self, config: GenerateConfig, http_options: HttpOptions
+    ) -> None:
         if self._batcher or not (batch_config := normalized_batch_config(config.batch)):
             return
+
+        # create a dedicated client instance for the batcher
+        client = Client(
+            vertexai=self.is_vertex(),
+            api_key=self.api_key,
+            http_options=http_options,
+            **self.model_args,
+        )
+
         self._batcher = GoogleBatcher(
             client,
             batch_config,
@@ -466,6 +517,7 @@ class GoogleGenAIAPI(ModelAPI):
                 config.max_retries,
                 config.timeout,
                 self.should_retry,
+                lambda ex: None,
                 log_model_retry,
             ),
             self.service_model_name(),
@@ -489,16 +541,28 @@ def build_model_call(
     safety_settings: list[SafetySettingDict],
     tools: ToolListUnion | None,
     tool_config: ToolConfig | None,
+    system_instruction: list[File | Part | Image | str] | None,
     response: GenerateContentResponse | None,
     time: float | None,
 ) -> ModelCall:
     return ModelCall.create(
         request=dict(
             contents=contents,
-            generation_config=generation_config,
+            # the excluded fields are passed to the Python API as part of
+            # GenerateContentConfig however they are passed separately in
+            # the actual http request body, so reflect that here
+            generation_config=generation_config.model_copy(
+                update={
+                    "safety_settings": None,
+                    "tools": None,
+                    "tool_config": None,
+                    "system_instruction": None,
+                }
+            ),
             safety_settings=safety_settings,
             tools=tools if tools is not None else None,
             tool_config=tool_config if tool_config is not None else None,
+            system_instruction=system_instruction,
         ),
         response=response if response is not None else {},
         filter=model_call_filter,
@@ -643,8 +707,8 @@ async def chat_content_to_part(
 async def extract_system_message_as_parts(
     client: Client,
     messages: list[ChatMessage],
-) -> list[File | Part | str] | None:
-    system_parts: list[File | Part | str] = []
+) -> list[File | Part | Image | str] | None:
+    system_parts: list[File | Part | Image | str] = []
     for message in messages:
         if message.role == "system":
             content = message.content
