@@ -30,6 +30,7 @@ from typing_extensions import override
 from inspect_ai._util.constants import DEFAULT_MAX_TOKENS
 from inspect_ai._util.content import (
     ContentAudio,
+    ContentDocument,
     ContentImage,
     ContentText,
     ContentVideo,
@@ -109,7 +110,7 @@ class HuggingFaceAPI(ModelAPI):
 
         # model
         if model_path:
-            self.model = AutoModelForCausalLM.from_pretrained(
+            self.model: Any = AutoModelForCausalLM.from_pretrained(
                 model_path, device_map=self.device, token=self.api_key, **model_args
             )
         else:
@@ -298,7 +299,9 @@ def message_content_to_string(messages: list[ChatMessage]) -> list[ChatMessage]:
     for message in messages:
         if isinstance(message.content, list):
             is_multimodal = any(
-                isinstance(item, ContentAudio | ContentImage | ContentVideo)
+                isinstance(
+                    item, ContentAudio | ContentImage | ContentVideo | ContentDocument
+                )
                 for item in message.content
             )
             if is_multimodal:
