@@ -4,6 +4,7 @@ from logging import getLogger
 from typing import Any
 
 from openai import (
+    APIStatusError,
     AsyncAzureOpenAI,
     AsyncOpenAI,
     NotGiven,
@@ -94,7 +95,7 @@ class OpenAIAPI(ModelAPI):
         )
 
         # set background bit (automatically use background for deep research)
-        if background is None and self.is_deep_research():
+        if background is None and (self.is_deep_research() or self.is_gpt_5_pro()):
             background = True
         self.background = background
 
@@ -103,7 +104,7 @@ class OpenAIAPI(ModelAPI):
             (self.is_o_series() and not self.is_o1_early())
             or self.is_codex()
             or self.is_gpt_5()
-        )
+        ) and config.num_choices is None
 
         # resolve whether we are forcing the responses api
         self.responses_api = (
@@ -126,7 +127,7 @@ class OpenAIAPI(ModelAPI):
         # resolve api_key or managed identity (for Azure)
         self.token_provider = None
         if not self.api_key:
-            if self.service == "azure":
+            if self.is_azure():
                 self.api_key = os.environ.get(
                     AZUREAI_OPENAI_API_KEY, os.environ.get(AZURE_OPENAI_API_KEY, None)
                 )
@@ -158,18 +159,34 @@ class OpenAIAPI(ModelAPI):
                     [
                         OPENAI_API_KEY,
                         AZUREAI_OPENAI_API_KEY,
-                        "or managed identity (Entra ID)",
+                        "managed identity (Entra ID)",
                     ],
                 )
 
-        # create async http client
-        http_client = model_args.pop("http_client", OpenAIAsyncHttpxClient())
+        # extract http_client and api_version before storing model_args
+        self.http_client = (
+            model_args.pop("http_client", None) or OpenAIAsyncHttpxClient()
+        )
+        if self.is_azure():
+            # resolve version
+            if model_args.get("api_version") is not None:
+                self.api_version = model_args.pop("api_version")
+            else:
+                self.api_version = os.environ.get(
+                    "AZUREAI_OPENAI_API_VERSION",
+                    os.environ.get("OPENAI_API_VERSION", "2025-03-01-preview"),
+                )
 
+        # store remaining model_args after extraction
+        self.model_args = model_args
+        self.initialize()
+
+    def _create_client(self) -> AsyncAzureOpenAI | AsyncOpenAI:
         # azure client
         if self.is_azure():
             # resolve base_url
             base_url = model_base_url(
-                base_url,
+                self.base_url,
                 [
                     "AZUREAI_OPENAI_BASE_URL",
                     "AZURE_OPENAI_BASE_URL",
@@ -182,39 +199,33 @@ class OpenAIAPI(ModelAPI):
                     + "environment variable or the --model-base-url CLI flag to set the base URL."
                 )
 
-            # resolve version
-            if model_args.get("api_version") is not None:
-                # use slightly complicated logic to allow for "api_version" to be removed
-                api_version = model_args.pop("api_version")
-            else:
-                api_version = os.environ.get(
-                    "AZUREAI_OPENAI_API_VERSION",
-                    os.environ.get("OPENAI_API_VERSION", "2025-03-01-preview"),
-                )
-
             # use managed identity if available, otherwise API key
-            self.client: AsyncAzureOpenAI | AsyncOpenAI = AsyncAzureOpenAI(
+            return AsyncAzureOpenAI(
                 api_key=self.api_key,
                 azure_ad_token_provider=self.token_provider,
-                api_version=api_version,
+                api_version=self.api_version,
                 azure_endpoint=base_url,
-                http_client=http_client,
+                http_client=self.http_client,
                 timeout=self.client_timeout
                 if self.client_timeout is not None
                 else NOT_GIVEN,
-                **model_args,
+                **self.model_args,
             )
         else:
-            self.client = AsyncOpenAI(
+            return AsyncOpenAI(
                 api_key=self.api_key,
-                base_url=model_base_url(base_url, "OPENAI_BASE_URL"),
-                http_client=http_client,
+                base_url=model_base_url(self.base_url, "OPENAI_BASE_URL"),
+                http_client=self.http_client,
                 timeout=self.client_timeout
                 if self.client_timeout is not None
                 else NOT_GIVEN,
-                **model_args,
+                **self.model_args,
             )
 
+    def initialize(self) -> None:
+        super().initialize()
+        self.client = self._create_client()
+
         # TODO: Although we could enhance OpenAIBatcher to support requests with
         # homogenous endpoints (e.g. some going to completions and some going to
         # responses), the code would have to be more complex to retain type safety.
@@ -223,8 +234,6 @@ class OpenAIAPI(ModelAPI):
         # side step that complexity and just use two different batchers.
         self._completions_batcher: OpenAIBatcher[ChatCompletion] | None = None
         self._responses_batcher: OpenAIBatcher[Response] | None = None
-
-        # create time tracker
         self._http_hooks = HttpxHooks(self.client._client)
 
     def is_azure(self) -> bool:
@@ -233,7 +242,7 @@ class OpenAIAPI(ModelAPI):
     def has_reasoning_options(self) -> bool:
         return (
             (self.is_o_series() and not self.is_o1_early())
-            or self.is_gpt_5()
+            or (self.is_gpt_5() and not self.is_gpt_5_chat())
             or self.is_codex()
         )
 
@@ -251,6 +260,14 @@ class OpenAIAPI(ModelAPI):
         name = self.service_model_name()
         return "gpt-5" in name
 
+    def is_gpt_5_pro(self) -> bool:
+        name = self.service_model_name()
+        return self.is_gpt_5() and "-pro" in name
+
+    def is_gpt_5_chat(self) -> bool:
+        name = self.service_model_name()
+        return self.is_gpt_5() and "-chat" in name
+
     def is_o1(self) -> bool:
         name = self.service_model_name()
         return "o1" in name and not self.is_o1_early()
@@ -290,7 +307,7 @@ class OpenAIAPI(ModelAPI):
     @override
     def tool_result_images(self) -> bool:
         # computer_use_preview supports tool calls returning images
-        if self.is_computer_use_preview():
+        if self.is_computer_use_preview() or self.responses_api:
             return True
         else:
             return False
@@ -361,6 +378,9 @@ class OpenAIAPI(ModelAPI):
         """Model name without any service prefix."""
         return self.model_name.replace(f"{self.service}/", "", 1)
 
+    def canonical_name(self) -> str:
+        return self.service_model_name()
+
     @override
     def should_retry(self, ex: BaseException) -> bool:
         if isinstance(ex, RateLimitError):
@@ -374,6 +394,12 @@ class OpenAIAPI(ModelAPI):
         else:
             return openai_should_retry(ex)
 
+    @override
+    def is_auth_failure(self, ex: Exception) -> bool:
+        if isinstance(ex, APIStatusError):
+            return ex.status_code == 401
+        return False
+
     @override
     def connection_key(self) -> str:
         """Scope for enforcing max_connections (could also use endpoint)."""
@@ -386,6 +412,7 @@ class OpenAIAPI(ModelAPI):
                 config.max_retries,
                 config.timeout,
                 self.should_retry,
+                lambda ex: None,
                 log_model_retry,
             )
 
