@@ -285,32 +285,21 @@ def none() -> type[ModelAPI]:
     return NoModel
 
 
-@modelapi("goodfire")
-def goodfire() -> type[ModelAPI]:
-    """Get the Goodfire API provider."""
-    FEATURE = "Goodfire API"
-    PACKAGE = "goodfire"
-    MIN_VERSION = "0.3.4"  # Support for newer Llama models and OpenAI compatibility
-
-    # verify we have the package
-    try:
-        import goodfire  # type: ignore # noqa: F401
-    except ImportError:
-        raise pip_dependency_error(FEATURE, [PACKAGE])
-
-    # verify version
-    verify_required_version(FEATURE, PACKAGE, MIN_VERSION)
+@modelapi(name="hf-inference-providers")
+def hf_inference_providers() -> type[ModelAPI]:
+    # validate
+    validate_openai_client("HF Inference Providers API")
 
     # in the clear
-    from .goodfire import GoodfireAPI  # type: ignore[attr-defined]
+    from .hf_inference_providers import HFInferenceProvidersAPI
 
-    return GoodfireAPI  # type: ignore[no-any-return]
+    return HFInferenceProvidersAPI
 
 
 def validate_openai_client(feature: str) -> None:
     FEATURE = feature
     PACKAGE = "openai"
-    MIN_VERSION = "1.104.1"
+    MIN_VERSION = "2.0.0"
 
     # verify we have the package
     try:
@@ -324,7 +313,7 @@ def validate_openai_client(feature: str) -> None:
 
 def validate_anthropic_client(feature: str) -> None:
     PACKAGE = "anthropic"
-    MIN_VERSION = "0.52.0"
+    MIN_VERSION = "0.69.0"
 
     # verify we have the package
     try:
