@@ -11,17 +11,12 @@ from inspect_ai.model import (
 from inspect_ai.util import json_schema
 
 
-@pytest.mark.anyio
+@pytest.mark.asyncio
 @skip_if_no_groq
-async def test_groq_api() -> None:
+async def test_core_groq_api() -> None:
     model = get_model(
-        "groq/llama3-70b-8192",
+        "groq/openai/gpt-oss-20b",
         config=GenerateConfig(
-            frequency_penalty=0.0,
-            stop_seqs=None,
-            max_tokens=50,
-            presence_penalty=0.0,
-            seed=None,
             temperature=0.0,
             top_p=1.0,
         ),
@@ -36,7 +31,7 @@ class NounPhrase(BaseModel):
     noun_phrase: str
 
 
-@pytest.mark.anyio
+@pytest.mark.asyncio
 @skip_if_no_groq
 async def test_groq_api_with_response_schema() -> None:
     model = get_model(
